@@ -2,7 +2,7 @@ use strict;
 use warnings;
 
 package Maven::Repositories;
-$Maven::Repositories::VERSION = '1.07';
+$Maven::Repositories::VERSION = '1.08';
 # ABSTRACT: An ordered collection of repositories from which to resolve artifacts
 # PODNAME: Maven::Repositories
 
@@ -29,15 +29,13 @@ sub add_central {
 }
 
 sub _artifact_not_found {
-    my ( $self, $options ) = @_;
-    my @options_entries = ();
-    foreach my $key ( keys(%$options) ) {
-        if ( $options->{$key} ) {
-            push( @options_entries, "$key=>$options->{$key}" );
-        }
-    }
-
-    return 'artifact not found for {' . join( '', @options_entries ) . '}';
+    my ( $self, $coordinate_or_artifact, $options ) = @_;
+    my $artifact =
+        ref($coordinate_or_artifact)
+        && UNIVERSAL::isa( $coordinate_or_artifact, 'Maven::Artifact' )
+        ? $coordinate_or_artifact
+        : Maven::Artifact->new( $coordinate_or_artifact, %$options )->get_coordinate();
+    return "artifact $artifact not found";
 }
 
 sub add_local {
@@ -93,8 +91,8 @@ sub resolve {
 
 sub resolve_or_die {
     my ( $self, $coordinate_or_artifact, %parts ) = @_;
-    my $resolved = resolve( $self, $coordinate_or_artifact, %parts );
-    croak( _artifact_not_found( $self, \%parts ) ) if ( !$resolved );
+    my $resolved = $self->resolve( $coordinate_or_artifact, %parts );
+    croak( $self->_artifact_not_found( $coordinate_or_artifact, \%parts ) ) if ( !$resolved );
 
     return $resolved;
 }
@@ -111,7 +109,7 @@ Maven::Repositories - An ordered collection of repositories from which to resolv
 
 =head1 VERSION
 
-version 1.07
+version 1.08
 
 =head1 SYNOPSIS
 
